#[non_exhaustive]pub enum CatalogError {
UnknownId {
family: IdFamily,
id: u64,
},
UnknownName {
kind: &'static str,
name: String,
},
DuplicateName,
DuplicateId,
SchemaConflict {
name: String,
reason: &'static str,
},
}Expand description
Errors from catalog identity: canonical ids, catalog names, and declared schema shapes.
Performance
Formatting is O(message length).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownId
A referenced canonical id is not present.
Fields
UnknownName
A catalog name was not found in a bound schema.
Fields
DuplicateName
Duplicate catalog name or ID.
DuplicateId
Duplicate canonical ID.
SchemaConflict
A declared schema item conflicts with an existing catalog entry.