#[non_exhaustive]pub enum DbError {
Show 27 variants
AlreadyExists,
NotFound,
WriterLockHeld,
IdOverflow,
TransactionIdOverflow,
CommitSeqOverflow,
DuplicateCatalogName,
DuplicateId,
UnknownElement {
id: ElementId,
},
UnknownRelation {
id: RelationId,
},
UnknownIncidence {
id: IncidenceId,
},
UnknownRole {
id: RoleId,
},
UnknownLabel {
id: LabelId,
},
UnknownRelationType {
id: RelationTypeId,
},
UnknownPropertyKey {
id: PropertyKeyId,
},
UnknownProjection {
id: ProjectionId,
},
UnknownIndex {
id: IndexId,
},
PropertyTypeMismatch {
expected: PropertyType,
actual: PropertyType,
},
WrongPropertyFamily {
expected: PropertyFamily,
actual: PropertyFamily,
},
InvalidProjection {
message: String,
},
EmptyQuery,
UnsupportedQuery {
message: String,
},
InvalidStore {
message: String,
},
Io {
operation: &'static str,
source: Error,
},
Traversal {
source: BfsError,
},
LogCorrupt {
lsn: u64,
reason: &'static str,
},
BaseGenerationMismatch {
expected: u64,
found: u64,
},
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AlreadyExists
Database files already exist.
NotFound
Database files do not exist.
WriterLockHeld
The single-writer lock is already held by another writer.
IdOverflow
Canonical ID space is exhausted.
TransactionIdOverflow
Transaction ID space is exhausted.
CommitSeqOverflow
Commit sequence space is exhausted.
DuplicateCatalogName
Duplicate catalog name or ID.
DuplicateId
Duplicate canonical ID.
UnknownElement
Unknown element ID.
UnknownRelation
Unknown relation ID.
Fields
id: RelationIdMissing relation ID.
UnknownIncidence
Unknown incidence ID.
Fields
id: IncidenceIdMissing incidence ID.
UnknownRole
Unknown role ID.
UnknownLabel
Unknown label ID.
UnknownRelationType
Unknown relation type ID.
Fields
id: RelationTypeIdMissing relation type ID.
UnknownPropertyKey
Unknown property key ID.
Fields
id: PropertyKeyIdMissing property key ID.
UnknownProjection
Unknown projection ID.
Fields
id: ProjectionIdMissing projection ID.
UnknownIndex
Unknown index ID.
PropertyTypeMismatch
Property value type mismatched the catalog schema.
WrongPropertyFamily
Property subject family mismatched the catalog schema.
Fields
expected: PropertyFamilyExpected subject family.
actual: PropertyFamilyActual subject family.
InvalidProjection
Projection cannot be materialized as requested.
EmptyQuery
Query text is empty.
UnsupportedQuery
Query text is outside the pinned profile.
InvalidStore
Storage bytes are invalid.
Io
Wraps an IO error with operation context.
Traversal
Wraps a substrate bounded-BFS traversal failure.
LogCorrupt
A delta-log record is corrupt beyond the recoverable torn tail.
Fields
BaseGenerationMismatch
A delta-log record names a different base generation than the superblock.