pub struct Schema { /* private fields */ }Expand description
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn relation_type(self, name: &str) -> Self
pub fn relation_type(self, name: &str) -> Self
Sourcepub fn key<T: ValueType>(self, name: &str, family: PropertyFamily) -> Self
pub fn key<T: ValueType>(self, name: &str, family: PropertyFamily) -> Self
Declares a typed property key in family whose value type is T.
Performance
This method is O(name length).
Sourcepub fn equality_index(self, name: &str, key: &str) -> Self
pub fn equality_index(self, name: &str, key: &str) -> Self
Declares an equality index named name over the property key key.
Performance
This method is O(name lengths).